@@ -18,7 +18,7 @@ def login(username,password):
 
 
 def excuteSql(username,password,excuteSql,sqlType):
-    API='http://daas.smartsteps.com/qsqltest/qsql/sqlexecute'
+    API='http://daas.smartsteps.com/qsql/sqlexecute'
     header = {"Content-Type":"application/x-www-form-urlencoded","Authorization":login(username,password)}
     data={
            "executeSql": excuteSql,
